==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Prohlížeč obrázků</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Prohlížeč obrázků je nástroj pro zobrazování obrázků, který má hezké rozhraní a je rychlý.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Tento soubor obsahuje vícero stránek – pro zobrazení všech použijte aplikaci Evince</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít složku</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemáte oprávnění k zobrazení obrázku</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Soubor s obrázkem nenalezen.</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Rozměr</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Zachyceno</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim expozice</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Expoziční program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Expoziční čas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdálenost</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Největší clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Režim měření</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyvážení bílé</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompenzace blesku</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektivu</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barevný prostor</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Značka</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Žádná změna velikosti</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Přizpůsobit stranu obrázku</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Přizpůsobit obrázek straně</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Změnit velikost na:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetry</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetry</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Palce</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Poloha obrázku</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Změna velikosti</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Nastavení obrázku</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Nastavení obrázku</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Rolování</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Přepínač</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Prstenec</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd.MM.yyyy hh:mm:ss</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Napište nový název</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Vybrat složku</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Synchronizace této složky je vypnutá</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Přidat složku</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Správa synchronizace složek</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Seznam složek je prázdný</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Zrušit synchronizaci</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Zařízení bylo odstraněno</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Tato složka už neexistuje</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Počítá se…</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Zobrazení obrázku</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončit promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Předchozí obrazovka</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Další obrazovka</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit zkratky</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Zadejte novou zkratku</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Zobrazit obrázek</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Vrátit na výchozí hodnoty</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončit promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavení promítání</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efekt přepínání</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Doba trvání</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Doba mezi přepnutími</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekund</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Velikost 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Přizpůsobit oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit vpravo</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit vlevo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Správa obrázků</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Velikost 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Přizpůsobit oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenalezeny žádné soubory s obrázky</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Soubor s obrázkem nenalezen</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavení promítání</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Doba trvání</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Časová osa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Přidat do nového alba</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odebrat z oblíbených</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Zobrazit okno navigace</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrýt okno navigace</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Všechny obrázky</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Kresba</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.3.orig.tar.xz: deepin-image-viewer-5.9.3/src/translations/deepin-image-viewer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Soubor s obrázkem nenalezen.</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Zobrazení obrázku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Rozpoznat text</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit doprava</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit doleva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit zkratky</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Prohlížeč obrázků</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Prohlížeč obrázků je nástroj pro zobrazování obrázků, který má hezké rozhraní a je rychlý.</translation>
    </message>
</context>
</TS>
